import re
from typing import Optional, Any, List


def regx_match(pattern, string, flags=0, first: bool = False, default: Optional[Any] = None):
    match_result = re.findall(pattern, string, flags=flags)
    if match_result and first is True:
        return match_result[0]
    elif match_result:
        return match_result
    else:
        return default


def for_to_regx_match(pattern_list: List, string, default: Optional[Any] = None, **kwargs):
    for pattern in pattern_list:
        value = regx_match(pattern, string, **kwargs)
        if value:
            return value

    return default



from setuptools import setup, find_packages

setup(
    name='easy_spider_tool',
    version='1.0.07',
    packages=find_packages(),
    license='MIT',
    author='hanxinkong',
    author_email='xinkonghan@gmail.com',
    description='简易、好用的爬虫工具,减少重复代码与文件冗余',
    long_description=open('README.md', encoding='utf-8').read(),
    long_description_content_type="text/markdown",
    install_requires=[
        # List your package's dependencies here
        "dateparser>=1.1.3",
        "jsonpath>=0.82",
        "pytz>=2023.3"
    ],
)
